Generates the solver methods used by the main function and the benchmarks.
This must be the last item in your lib.rs.
This macro optionally accept with_benchmarks as an argument to generate the code required by
aoc_bench
Example
aoc_helper::aoc_lib!(with_benchmarks);